"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadUserMigrationFile = void 0;
const path_1 = __importDefault(require("path"));
const import_fresh_1 = __importDefault(require("import-fresh"));
/**
 *
 * @param migration migration instance
 * @param migrationFile An absolute path to the users migration file
 */
const loadUserMigrationFile = async (migration, migrationFile) => {
    return new Promise((resolve) => {
        // Load user's migration file
        const migrate = async (title, fn) => {
            migration.title = title;
            migration.events.emit('migration-start', { migration });
            await fn(migration.registerMethods, {
                ...migration.options,
                fs: migration.fs,
            });
            resolve();
        };
        // @ts-expect-error not sure how to type this
        globalThis.migrate = migrate;
        if (migrationFile.endsWith('.ts')) {
            require('ts-node').register({
                dir: path_1.default.dirname(migrationFile),
                transpileOnly: true,
                ignore: [],
            });
        }
        if (typeof jest !== 'undefined') {
            jest.doMock('code-migrate', () => {
                return {
                    __esModule: true,
                    migrate,
                };
            });
        }
        else {
            require('mock-require')('code-migrate', {
                migrate,
            });
        }
        import_fresh_1.default(migrationFile);
    });
};
exports.loadUserMigrationFile = loadUserMigrationFile;
