"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMarkdownReport = exports.formatSingleTaskError = exports.formatSingleTaskResult = void 0;
const lodash_1 = require("lodash");
const formatSingleTaskResult = (taskResult) => {
    switch (taskResult.type) {
        case 'transform': {
            return taskResult.newFile.fileName;
        }
        case 'create': {
            return taskResult.newFile.fileName;
        }
        case 'remove': {
            return taskResult.file.fileName;
        }
        case 'rename': {
            const { originalFile, newFile } = taskResult;
            return `${originalFile.fileName} -> ${newFile.fileName}`;
        }
        default: {
            // @ts-expect-error ts thinks that task is "never"
            throw new Error(`unknown taskResult type "${taskResult.type}"`);
        }
    }
};
exports.formatSingleTaskResult = formatSingleTaskResult;
const formatSingleTaskError = (taskError) => {
    var _a;
    return (`**ERROR** \`${(_a = taskError.file) === null || _a === void 0 ? void 0 : _a.fileName}\`\n` +
        '```\n' +
        taskError.error.stack +
        '\n```');
};
exports.formatSingleTaskError = formatSingleTaskError;
const createMarkdownReport = (migration) => {
    const output = [];
    output.push(`## ${migration.title}
> ${migration.options.cwd}`);
    for (const [taskTitle, taskResults] of Object.entries(lodash_1.groupBy(migration.results, 'task.title'))) {
        output.push(`#### ${taskTitle}` +
            '\n' +
            '```\n' +
            taskResults.map(exports.formatSingleTaskResult).join('\n') +
            '\n```');
    }
    if (migration.errors.length > 0) {
        output.push('### ⚠️  ' + `The following migration tasks were failed`);
        for (const [taskTitle, taskErrors] of Object.entries(lodash_1.groupBy(migration.errors, 'task.title'))) {
            output.push(`#### ${taskTitle}` +
                '\n' +
                taskErrors.map(exports.formatSingleTaskError).join('\n'));
        }
    }
    if (lodash_1.isEmpty(migration.results)) {
        output.push('**🤷‍ No changes have been made**');
    }
    return output.join('\n\n');
};
exports.createMarkdownReport = createMarkdownReport;
