"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runMigration = void 0;
const prompts_1 = __importDefault(require("prompts"));
const Migration_1 = require("./Migration");
const loadUserMigrationFile_1 = require("./loadUserMigrationFile");
const lodash_1 = require("lodash");
const writeReportFile_1 = require("./reporters/writeReportFile");
/**
 *
 * @param options.cwd The directory of the project which the migration runs on
 * @param options.migrationFilePath path to the migration file
 * @param options.dry Dry run mode
 * @param options.yes Do not prompt the user with confirmation
 * Run a migration
 * @param options.reporter Use a custom reporter ("default"/"quiet"/"markdown")
 * @param options.reportFile Create a markdown report and output it to a file
 *
 */
const runMigration = async ({ cwd, migrationFilePath, dry, yes, reporter, reportFile, }) => {
    const migration = Migration_1.Migration.init({ cwd, reporter });
    const { events } = migration;
    await loadUserMigrationFile_1.loadUserMigrationFile(migration, migrationFilePath);
    events.emit('migration-after-run', {
        migration,
        options: { dry, reportFile },
    });
    if (lodash_1.isEmpty(migration.results)) {
        process.exit(0);
    }
    if (!yes && !dry) {
        events.emit('migration-before-prompt');
        const response = await prompts_1.default({
            type: 'confirm',
            name: 'value',
            message: `Press 'y' to execute the migration on the above files`,
            initial: true,
        });
        if (!response.value) {
            events.emit('migration-after-prompt-aborted');
            process.exit(1);
        }
        events.emit('migration-after-prompt-confirmed');
    }
    if (!dry) {
        migration.write();
        events.emit('migration-after-write');
    }
    if (reportFile) {
        writeReportFile_1.writeReportFile(migration, reportFile);
    }
};
exports.runMigration = runMigration;
